@@ -1,9 +1,14 @@
 use crate::date_utils as GitQLDate;
 use crate::regex_utils as GitQLRegex;
+use crate::types::same_type_as_first_parameter;
 use crate::types::DataType;
 use crate::value::Value;
 
 use lazy_static::lazy_static;
+use rand::distributions::Uniform;
+use rand::rngs::StdRng;
+use rand::Rng;
+use rand::SeedableRng;
 use std::cmp::Ordering;
 use std::collections::HashMap;
 use std::ops::Rem;
@@ -87,6 +92,7 @@ lazy_static! {
         map.insert("atn2", numeric_atn2);
         map.insert("sign", numeric_sign);
         map.insert("mod", numeric_mod);
+        map.insert("rand", numeric_rand);
 
         // Other Functions
         map.insert("isnull", general_is_null);
@@ -458,8 +464,8 @@ lazy_static! {
         map.insert(
             "abs",
             Prototype {
-                parameters: vec![DataType::Integer],
-                result: DataType::Integer,
+                parameters: vec![DataType::Variant(vec![DataType::Integer, DataType::Float])],
+                result: DataType::Dynamic(same_type_as_first_parameter),
             },
         );
         map.insert(
@@ -553,6 +559,13 @@ lazy_static! {
                 result: DataType::Integer,
             },
         );
+        map.insert(
+            "rand",
+            Prototype {
+                parameters: vec![DataType::Optional(Box::new(DataType::Float))],
+                result: DataType::Float,
+            },
+        );
         // General functions
         map.insert(
             "isnull",
@@ -602,7 +615,7 @@ lazy_static! {
             "regexp_like",
             Prototype {
                 parameters: vec![DataType::Text, DataType::Text],
-                result: DataType::Integer,
+                result: DataType::Boolean,
             },
         );
         map.insert(
@@ -1017,8 +1030,11 @@ fn date_last_day(inputs: &[Value]) -> Value {
 // Numeric functions
 
 fn numeric_abs(inputs: &[Value]) -> Value {
-    let value = inputs[0].as_int();
-    Value::Integer(value.abs())
+    let input_type = inputs[0].data_type();
+    if input_type.is_float() {
+        return Value::Float(inputs[0].as_float().abs());
+    }
+    Value::Integer(inputs[0].as_int().abs())
 }
 
 fn numeric_pi(_inputs: &[Value]) -> Value {
@@ -1111,6 +1127,14 @@ fn numeric_mod(inputs: &[Value]) -> Value {
     Value::Integer(first.as_int().rem(other.as_int()))
 }
 
+fn numeric_rand(inputs: &[Value]) -> Value {
+    let mut rng: StdRng = match inputs.first() {
+        Some(s) => SeedableRng::seed_from_u64(s.as_int().try_into().unwrap()),
+        None => SeedableRng::from_entropy(),
+    };
+    Value::Float(rng.sample(Uniform::from(0.0..1.0)))
+}
+
 // General functions
 
 fn general_is_null(inputs: &[Value]) -> Value {
@@ -1163,11 +1187,7 @@ fn regexp_instr(inputs: &[Value]) -> Value {
 fn regexp_like(inputs: &[Value]) -> Value {
     let input = inputs[0].as_text();
     let pattern = inputs[1].as_text();
-    Value::Integer(if GitQLRegex::regex_is_match(&input, &pattern) {
-        1
-    } else {
-        0
-    })
+    Value::Boolean(GitQLRegex::regex_is_match(&input, &pattern))
 }
 
 fn regexp_replace(inputs: &[Value]) -> Value {
