@@ -316,6 +316,16 @@ fn parse_select_query(
                 let statement = parse_order_by_statement(&mut context, env, tokens, position)?;
                 statements.insert("order", statement);
             }
+            TokenKind::Not => {
+                return Err(Diagnostic::error(
+                    "Expects `REGEXP` or `IN` expression after this `NOT` keyword",
+                )
+                .add_help("Try to use `REGEXP` or `IN` expression after NOT keyword")
+                .add_help("Try to remove `NOT` keyword")
+                .add_note("Expect to see `NOT` then `IN` keyword with a list of values")
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed())
+            }
             _ => break,
         }
     }
@@ -460,9 +470,6 @@ fn parse_select_statement(
                 .as_boxed());
         }
 
-        // Consume table name
-        *position += 1;
-
         table_name = &table_name_token.ok().unwrap().literal;
         if !env.schema.tables_fields_names.contains_key(table_name) {
             return Err(Diagnostic::error("Unresolved table name")
@@ -471,6 +478,9 @@ fn parse_select_statement(
                 .as_boxed());
         }
 
+        // Consume table name
+        *position += 1;
+
         register_current_table_fields_types(env, table_name);
     }
 
@@ -806,7 +816,7 @@ fn parse_assignment_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_is_null_expression(context, env, tokens, position)?;
+    let expression = parse_regex_expression(context, env, tokens, position)?;
     if *position < tokens.len() && tokens[*position].kind == TokenKind::ColonEqual {
         if expression.kind() != ExpressionKind::GlobalVariable {
             return Err(Diagnostic::error(
@@ -826,7 +836,7 @@ fn parse_assignment_expression(
         // Consume `:=` operator
         *position += 1;
 
-        let value = parse_is_null_expression(context, env, tokens, position)?;
+        let value = parse_regex_expression(context, env, tokens, position)?;
         env.define_global(variable_name.clone(), value.expr_type(env));
 
         return Ok(Box::new(AssignmentExpression {
@@ -837,6 +847,64 @@ fn parse_assignment_expression(
     Ok(expression)
 }
 
+fn parse_regex_expression(
+    context: &mut ParserContext,
+    env: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
+    let expression = parse_is_null_expression(context, env, tokens, position)?;
+
+    // Consume NOT if current token is `RegExp` and next one is `IN`
+    let has_not_keyword = if *position < tokens.len() - 1
+        && tokens[*position].kind == TokenKind::Not
+        && tokens[*position + 1].kind == TokenKind::RegExp
+    {
+        *position += 1;
+        true
+    } else {
+        false
+    };
+
+    if *position < tokens.len() && tokens[*position].kind == TokenKind::RegExp {
+        if !expression.expr_type(env).is_text() {
+            return Err(
+                Diagnostic::error("`REGEXP` left hand side must be `Text` Type")
+                    .with_location(tokens[*position].location)
+                    .as_boxed(),
+            );
+        }
+
+        *position += 1;
+
+        let pattern = parse_is_null_expression(context, env, tokens, position)?;
+        if !pattern.expr_type(env).is_text() {
+            return Err(
+                Diagnostic::error("`REGEXP` right hand side must be `Text` Type")
+                    .with_location(tokens[*position].location)
+                    .as_boxed(),
+            );
+        }
+
+        let regex_expr = Box::new(CallExpression {
+            function_name: "regexp_like".to_owned(),
+            arguments: vec![expression, pattern],
+            is_aggregation: false,
+        });
+
+        return Ok(if has_not_keyword {
+            Box::new(PrefixUnary {
+                right: regex_expr,
+                op: PrefixUnaryOperator::Bang,
+            })
+        } else {
+            regex_expr
+        });
+    }
+
+    Ok(expression)
+}
+
 fn parse_is_null_expression(
     context: &mut ParserContext,
     env: &mut Environment,
@@ -886,8 +954,11 @@ fn parse_in_expression(
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
     let expression = parse_between_expression(context, env, tokens, position)?;
 
-    // Consume `NOT` keyword if IN Expression prefixed with `NOT` for example `expr NOT IN (...values)`
-    let has_not_keyword = if *position < tokens.len() && tokens[*position].kind == TokenKind::Not {
+    // Consume NOT if current token is `NOT` and next one is `IN`
+    let has_not_keyword = if *position < tokens.len() - 1
+        && tokens[*position].kind == TokenKind::Not
+        && tokens[*position + 1].kind == TokenKind::In
+    {
         *position += 1;
         true
     } else {
@@ -944,18 +1015,6 @@ fn parse_in_expression(
         }));
     }
 
-    // Report error if user write `NOT` with no `IN` keyword after it
-    if has_not_keyword {
-        return Err(
-            Diagnostic::error("Expects `IN` expression after this `NOT` keyword")
-                .add_help("Try to use `IN` expression after NOT keyword")
-                .add_help("Try to remove `NOT` keyword")
-                .add_note("Expect to see `NOT` then `IN` keyword with a list of values")
-                .with_location(get_safe_location(tokens, *position - 1))
-                .as_boxed(),
-        );
-    }
-
     Ok(expression)
 }
 
@@ -1621,7 +1680,7 @@ fn parse_unary_expression(
             ));
         }
 
-        if op == PrefixUnaryOperator::Minus && rhs_type != DataType::Integer {
+        if op == PrefixUnaryOperator::Minus && !rhs_type.is_number() {
             return Err(type_mismatch_error(
                 get_safe_location(tokens, *position - 1),
                 DataType::Integer,
@@ -1687,7 +1746,7 @@ fn parse_function_call_expression(
         if AGGREGATIONS.contains_key(function_name.as_str()) {
             let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
             let prototype = AGGREGATIONS_PROTOS.get(function_name.as_str()).unwrap();
-            let parameters = &vec![prototype.parameter.clone()];
+            let parameters = &[prototype.parameter.clone()];
             let mut return_type = prototype.result.clone();
             if let DataType::Dynamic(calculate_type) = return_type {
                 return_type = calculate_type(parameters);
